@@ -9,7 +9,6 @@ def initialiseprogress(self, experiment):
     """
     self.progress["ignoredwells"][experiment] = []
     self.progress["negativevalues"][experiment] = False
-    self.progress["gc"][experiment] = None
 
 
 ###
@@ -44,19 +43,13 @@ def make_s(self, tmin=None, tmax=None):
         rdf = self.r
     # find means
     df1 = (
-        rdf.groupby(["experiment", "condition", "strain", "time"])
-        .mean()
-        .reset_index()
+        rdf.groupby(["experiment", "condition", "strain", "time"]).mean().reset_index()
     )
     for exp in self.allexperiments:
         for dtype in self.datatypes[exp]:
             df1 = df1.rename(columns={dtype: dtype + " mean"})
     # find errors
-    df2 = (
-        rdf.groupby(["experiment", "condition", "strain", "time"])
-        .std()
-        .reset_index()
-    )
+    df2 = rdf.groupby(["experiment", "condition", "strain", "time"]).std().reset_index()
     for exp in self.allexperiments:
         for dtype in self.datatypes[exp]:
             df2 = df2.rename(columns={dtype: dtype + " err"})
@@ -75,4 +68,6 @@ def update_s(self):
     tmax = self.s.time.max()
     # recalculate s dataframe
     self.s = make_s(self, tmin, tmax)
+
+
 ###
