@@ -5,7 +5,7 @@ import functools
 
 
 def initlog(version=None):
-    """Enable logging."""
+    # enable logging
     starttime = "{:%Y-%b-%d %H:%M:%S}".format(datetime.datetime.now())
     logger = logging.getLogger(__name__)
     logger.setLevel(logging.INFO)
@@ -24,7 +24,6 @@ def initlog(version=None):
 
 
 def log(func):
-    """To decorate functions whose output should be logged."""
     @functools.wraps(func)
     def wrapper(self, *args, **kwargs):
         res = func(self, *args, **kwargs)
