@@ -12,7 +12,7 @@ import om_code.omerrors as errors
 import om_code.omgenutils as gu
 
 
-def findODcorrection(wdirpath, ODfname, exp, figs, odmatch, cvfn, bd, gp_results):
+def findODcorrection(wdirpath, ODfname, figs, odmatch, cvfn, bd, gp_results):
     """
     Uses a Gaussian process to fit serial dilution data
     to correct for non-linearities in the relationship between OD and cell
@@ -21,7 +21,7 @@ def findODcorrection(wdirpath, ODfname, exp, figs, odmatch, cvfn, bd, gp_results
     L Bandiera).
     """
     print("Fitting dilution data for OD correction for non-linearities")
-    if ODfname:
+    if ODfname is not None:
         try:
             od_df = pd.read_csv(
                 str(wdirpath / ODfname), sep=None, engine="python", header=None
@@ -165,7 +165,7 @@ def findODcorrection(wdirpath, ODfname, exp, figs, odmatch, cvfn, bd, gp_results
     # process data
     dilfac = dilfac[np.argsort(od)]
     od = np.sort(od)
-    if odmatch:
+    if odmatch is not None:
         # rescale so that OD and dilfac match at a particular OD
         # compares better with Warringer & Blomberg, Yeast 2003,
         # and rescaled OD is larger
