@@ -9,7 +9,8 @@ import om_code.omgenutils as gu
 
 class fitderiv:
     """
-    Smooth and estimate the time derivative of the data via Gaussian processes.
+    to smooth data and estimate the time derivative of the data using Gaussian
+    processes.
 
     Summary statistics - the maximal time derivative, the time at which the
     maximal time derivative occurs, the timescale found from inverting the
@@ -47,6 +48,7 @@ class fitderiv:
     ds: dictionary
         The summary statistics and their estimated errors.
 
+
     Examples
     --------
     A typical work flow is:
@@ -79,7 +81,7 @@ class fitderiv:
         exitearly=False,
         bd=False,
         empirical_errors=False,
-        optmethod="L-BFGS-B",
+        optmethod="l_bfgs_b",
         nosamples=100,
         stats=True,
         statnames=False,
@@ -89,9 +91,8 @@ class fitderiv:
         iskip=False,
     ):
         """
-        Smooth data and estimate its time derivatives.
-
-        The Gaussian process used performs both tasks.
+        Runs a Gaussian process to both smooth time-series data and estimate
+        its time-derivatives.
 
         Parameters
         ----------
@@ -199,7 +200,7 @@ class fitderiv:
                 bds = bddict[cvfn]
             gt = getattr(gp, cvfn + "GP")(bds, t, d)
             print("Using a " + gt.description + ".")
-            gt.info
+            gt.info()
         except NameError:
             raise (SystemExit("Gaussian process not recognised"))
         self.bds = bds
@@ -208,10 +209,8 @@ class fitderiv:
         if logs:
             print("Taking natural logarithm of the data")
             if np.any(np.nonzero(d < 0)):
-                print(
-                    "Negative data found, but all data must be positive "
-                    "if taking logs"
-                )
+                print("Negative data found, but all data must be positive "
+                      "if taking logs")
                 self.success = False
             else:
                 # replace zeros by machine error so that logs can be applied
@@ -222,7 +221,8 @@ class fitderiv:
         if empirical_errors:
             # errors must be empirically estimated
             if noreps > 1:
-                lod = [np.count_nonzero(np.isnan(d[:, i])) for i in range(noreps)]
+                lod = [np.count_nonzero(np.isnan(d[:, i]))
+                       for i in range(noreps)]
                 if np.sum(np.diff(lod)) != 0:
                     print(
                         "The replicates have different number of data "
@@ -266,37 +266,16 @@ class fitderiv:
         else:
             ma = None
         if self.success:
-            self.run(
-                cvfn,
-                ta,
-                da,
-                ma,
-                noruns,
-                noinits,
-                exitearly,
-                optmethod,
-                stats,
-                nosamples,
-                statnames,
-                showstaterrors,
-            )
+            self.run(cvfn, ta, da, ma, noruns, noinits, exitearly, optmethod,
+                     stats, nosamples, statnames, showstaterrors)
 
-    def run(
-        self,
-        cvfn,
-        ta,
-        da,
-        ma,
-        noruns,
-        noinits,
-        exitearly,
-        optmethod,
-        stats,
-        nosamples,
-        statnames,
-        showstaterrors,
-    ):
-        """Instantiate and run a Gaussian process."""
+    ###
+
+    def run(self, cvfn, ta, da, ma, noruns, noinits, exitearly, optmethod,
+            stats, nosamples, statnames, showstaterrors):
+        """
+        Instantiates and runs Gaussian process
+        """
         # instantiate Gaussian process
         g = getattr(gp, cvfn + "GP")(self.bds, ta, da, merrors=ma)
         # optimise parameters
@@ -331,12 +310,12 @@ class fitderiv:
         if stats:
             self.calculatestats(nosamples, statnames, showstaterrors)
 
+    ###
+
     def fitderivsample(self, nosamples, newt=None):
         """
-        Generate samples from the latent function.
-
-        Both values for the latent function and its first two
-        derivatives are returned, as a tuple.
+        Generate sample values for the latent function and its first two
+        derivatives (returned as a tuple).
 
         Parameters
         ----------
@@ -364,10 +343,12 @@ class fitderiv:
         samples = gps.sample(nosamples, derivs=2)
         return samples
 
+    ###
+
     def calculatestats(self, nosamples=100, statnames=None, showerrors=True):
         """
-        Calculate statistics from the smoothed data.
-
+        Calculates the statistics from the smoothed data and the inferred time
+        derivative.
         The default names are 'max df', 'time of max df', 'inverse max grad',
         'max f', and 'lag time'.
 
@@ -404,7 +385,9 @@ class fitderiv:
         dt = np.log(2) / mgr
         # lag time
         lagtime = (
-            tmgr + (fs[0, np.arange(nosamples)] - fs[im, np.arange(nosamples)]) / mgr
+            tmgr
+            + (fs[0, np.arange(nosamples)] - fs[im, np.arange(nosamples)])
+            / mgr
         )
         # store stats
         ds = {}
@@ -415,12 +398,12 @@ class fitderiv:
         self.nosamples = nosamples
         self.printstats(showerrors=showerrors)
 
+    ###
+
     def printstats(self, showerrors=True, performprint=True):
         """
-        Create and print a dictionary of statistics.
-
-        The statistics are calculated from the smoothed data and its
-        inferred time-derivatives.
+        Creates and potentially displays a dictionary of the statistics
+        calculated from the smoothed data and its inferred time-derivatives.
 
         Parameters
         ----------
@@ -444,20 +427,22 @@ class fitderiv:
                 stname = s.rjust(lenstr + 1)
                 if showerrors:
                     print(
-                        "{:s}= {:6e} +/- {:6e}".format(stname, statd[s], ds[s + " err"])
+                        "{:s}= {:6e} +/- {:6e}".format(
+                            stname, statd[s], ds[s + " err"]
+                        )
                     )
                 else:
                     print("{:s}= {:6e}".format(stname, statd[s]))
         return statd
 
+    ###
+
     def plotfit(
         self, char="f", errorfac=1, xlabel="time", ylabel=False, figtitle=False
     ):
         """
-        Plot the results of the fitting.
-
-        Either the data and the mean of the optimal Gaussian process or
-        the inferred time derivatives are plotted.
+        Plots either the data and the mean of the optimal Gaussian process or
+        the inferred time derivatives.
 
         Parameters
         ----------
