@@ -44,9 +44,7 @@ def plotplate(basedf, exps, dtype):
             coll = int(pl[1:])
             sindex = coll + 12 * rowl
             wd = basedf.query("experiment == @e and well == @pl")
-            ax[sindex - 1].plot(
-                wd["time"].to_numpy(), wd[dtype].to_numpy(), "-"
-            )
+            ax[sindex - 1].plot(wd["time"].to_numpy(), wd[dtype].to_numpy(), "-")
         plt.suptitle(e + ": " + dtype)
         plt.show()
 
@@ -66,7 +64,8 @@ def plot_wells(
     kind="line",
     col=None,
     row=None,
-    ymin=None,
+    xlim=None,
+    ylim=None,
     title=None,
     figsize=None,
     messages=False,
@@ -97,8 +96,10 @@ def plot_wells(
                 sfig.fig.suptitle(title)
             else:
                 sfig.fig.suptitle(e)
-            if ymin:
-                plt.ylim(ymin, None)
+            if xlim is not None:
+                plt.xlim(xlim)
+            if ylim is not None:
+                plt.ylim(ylim)
             if figsize and len(figsize) == 2:
                 sfig.fig.set_figwidth(figsize[0])
                 sfig.fig.set_figheight(figsize[1])
@@ -129,8 +130,10 @@ def plot_wells(
                             sfig.fig.suptitle(title)
                         else:
                             sfig.fig.suptitle(e + ": " + s + " in " + c)
-                        if ymin:
-                            plt.ylim(ymin, None)
+                        if xlim is not None:
+                            plt.xlim(xlim)
+                        if ylim is not None:
+                            plt.ylim(ylim)
                         plt.tight_layout()
                         plt.show()
 
@@ -153,7 +156,8 @@ def plot_rs(
     row=None,
     height=5,
     aspect=1,
-    ymin=None,
+    xlim=None,
+    ylim=None,
     title=None,
     figsize=None,
     sortby=False,
@@ -164,9 +168,7 @@ def plot_rs(
     Plots time-series data from the .r or .s dataframes.
     """
     # plot time series
-    df = basedf.query(
-        "experiment == @exps and condition == @cons and strain == @strs"
-    )
+    df = basedf.query("experiment == @exps and condition == @cons and strain == @strs")
     if df.empty:
         print("No data found")
     else:
@@ -215,8 +217,10 @@ def plot_rs(
         )
         if title:
             sfig.fig.suptitle(title)
-        if ymin is not None:
-            sfig.set(ylim=(ymin, None))
+        if xlim is not None:
+            sfig.set(xlim=xlim)
+        if ylim is not None:
+            sfig.set(ylim=ylim)
         if figsize and len(figsize) == 2:
             sfig.fig.set_figwidth(figsize[0])
             sfig.fig.set_figheight(figsize[1])
@@ -245,7 +249,8 @@ def plot_sc(
     row=None,
     height=5,
     aspect=1,
-    ymin=None,
+    xlim=None,
+    ylim=None,
     figsize=None,
     title=None,
     sortby=False,
@@ -255,15 +260,11 @@ def plot_sc(
     Plots summary statistics from the .sc dataframe.
     """
     # plot summary stats
-    df = basedf.query(
-        "experiment == @exps and condition == @cons and strain == @strs"
-    )
+    df = basedf.query("experiment == @exps and condition == @cons and strain == @strs")
     xcols = df.columns[df.columns.str.startswith(x)]
     ycols = df.columns[df.columns.str.startswith(y)]
     df = df[
-        np.unique(
-            ["experiment", "condition", "strain"] + list(xcols) + list(ycols)
-        )
+        np.unique(["experiment", "condition", "strain"] + list(xcols) + list(ycols))
     ].dropna()
     if df.empty:
         print("No data found")
@@ -284,8 +285,10 @@ def plot_sc(
             height=height,
             **kwargs,
         )
-        if ymin is not None:
-            sfig.set(ylim=(ymin, None))
+        if xlim is not None:
+            sfig.set(xlim=xlim)
+        if ylim is not None:
+            sfig.set(ylim=ylim)
         if row is None and col is None:
             # add error bars
             # find coordinates of points in relplot
@@ -384,11 +387,11 @@ def augmentdf(df, datatype):
         err = df[derr].to_numpy()
         # add std
         dfp = df.copy()
-        dfp[datatype] = mn + np.sqrt(3/2) * err
+        dfp[datatype] = mn + np.sqrt(3 / 2) * err
         dfp["augtype"] = "+err"
         # minus std
         dfm = df.copy()
-        dfm[datatype] = mn - np.sqrt(3/2) * err
+        dfm[datatype] = mn - np.sqrt(3 / 2) * err
         dfm["augtype"] = "-err"
         # concat
         df = pd.concat([df, dfp, dfm], ignore_index=True)
