@@ -18,7 +18,7 @@ import om_code.omstats as omstats
 import om_code.admin as admin
 import om_code.clogger as clogger
 
-version = "0.9.47"
+version = "0.9.50"
 
 plt.rcParams["figure.max_open_warning"] = 0
 sns.set()
@@ -133,10 +133,6 @@ class platereader:
         asheetnumbers: integer or list of integers, optional
             The relevant sheets of the corresponding Excel files for the
             annotation.
-        ODfname: string, optional
-            The name of the file with the dilution data used to correct OD for
-            its non-linear dependence on numbers of cells. If unspecified, data
-            for haploid budding yeast growing in glucose is used.
         info: boolean
             If True (default), display summary information on the data once
             loaded.
@@ -149,8 +145,6 @@ class platereader:
         self.wdirpath = Path(wdir)
 
         # enable logging
-        # self._initialiselogging()
-        # self._logmethod(self.logger)
         self.logger, self.logstream = clogger.initlog(version)
 
         if True:
@@ -162,8 +156,6 @@ class platereader:
         self.progress = {
             "ignoredwells": {},
             "negativevalues": {},
-            "ODfname": {},
-            "gc": {},
         }
         self.allexperiments = []
         self.allconditions = {}
@@ -182,7 +174,6 @@ class platereader:
                 platereadertype,
                 dsheetnumbers,
                 asheetnumbers,
-                ODfname,
                 info,
             )
 
@@ -206,10 +197,9 @@ class platereader:
         Example
         -------
         >>> p.ls
-        >>> p.ds
-        >>> p.load(p.ds[0], p.ds[1])
+        >>> p.files
+        >>> p.load(p.files[0], p.files[1])
         """
-        self.ds = {}
         print("Working directory is", str(self.wdirpath.resolve()))
         print("Files available are:", "\n---")
         files = []
@@ -224,7 +214,7 @@ class platereader:
                 print(f.stem + f.suffix)
                 files.append(f.stem + f.suffix)
         print()
-        self.ds = {i: f for i, f in enumerate(sorted(files))}
+        self.files = {i: f for i, f in enumerate(sorted(files))}
 
     ###
 
@@ -254,7 +244,6 @@ class platereader:
         platereadertype="Tecan",
         dsheetnumbers=False,
         asheetnumbers=False,
-        ODfname=None,
         info=True,
     ):
         """
@@ -277,10 +266,6 @@ class platereader:
         asheetnumbers: integer or list of integers, optional
             The relevant sheets of the corresponding Excel files for the
             annotation.
-        ODfname: string, optional
-            The name of the file with the dilution data used to correct OD for
-            its non-linear dependence on numbers of cells. If unspecified, data
-            for haploid budding yeast growing in glucose is used.
         info: boolean
             If True (default), display summary information on the data once
             loaded.
@@ -289,8 +274,6 @@ class platereader:
         -------
         >>> p.load('Data.xlsx', 'DataContents.xlsx')
         >>> p.load('Data.xlsx', 'DataContents.xlsx', info= False)
-        >>> p.load('Data.xlsx', 'DataContents.xlsx',
-        ...         ODfname= 'ODcorrection_Glucose_Diploid.txt')
         """
         dnames = gu.makelist(dnames)
         if not anames:
@@ -329,17 +312,6 @@ class platereader:
             # update progress dictionary
             admin.initialiseprogress(self, experiment)
 
-        # define ODfname in progress dictionary
-        if ODfname:
-            if isinstance(ODfname, str):
-                self.progress["ODfname"] = {exp: ODfname for exp in self.allexperiments}
-            else:
-                self.progress["ODfname"] = {
-                    exp: ODfname[i] for i, exp in enumerate(self.allexperiments)
-                }
-        else:
-            self.progress["ODfname"] = {exp: None for exp in self.allexperiments}
-
         # dataframe for summary stats and corrections
         alldfs = []
         # for exp in self.allexperiments:
@@ -1206,7 +1178,8 @@ class platereader:
         row=None,
         height=5,
         aspect=1,
-        ymin=None,
+        xlim=None,
+        ylim=None,
         figsize=False,
         returnfacetgrid=False,
         title=None,
@@ -1261,8 +1234,10 @@ class platereader:
         aspect: float, optional
             The aspect ratio of the individual panels in a multipanel plot.
             From Seaborn.
-        ymin: float, optional
-            The minimum y-value
+        xlim: list of two floats, optional
+            The minimal and maximal x-value, such as [0, None]
+        ylim: list of two floats, optional
+            The minimal and maximal y-value, such as [0, None]
         figsize: tuple, optional
             A tuple of (width, height) for the size of figure.
             Ignored if wells= True or plate= True.
@@ -1360,13 +1335,14 @@ class platereader:
                 kind,
                 col,
                 row,
-                ymin,
+                xlim,
+                ylim,
                 title,
                 messages,
                 **kwargs,
             )
         elif dfname == "s" or dfname == "r":
-            omplot.plot_rs(
+            sfig = omplot.plot_rs(
                 x,
                 y,
                 basedf,
@@ -1381,13 +1357,16 @@ class platereader:
                 row,
                 height,
                 aspect,
-                ymin,
+                xlim,
+                ylim,
                 title,
                 figsize,
                 sortby,
                 returnfacetgrid,
                 **kwargs,
             )
+            if returnfacetgrid:
+                return sfig
         elif dfname == "sc":
             omplot.plot_sc(
                 x,
@@ -1404,7 +1383,8 @@ class platereader:
                 row,
                 height,
                 aspect,
-                ymin,
+                xlim,
+                ylim,
                 figsize,
                 title,
                 sortby,
@@ -1559,6 +1539,7 @@ class platereader:
         cvfn="sqexplin",
         bd=None,
         gp_results=False,
+        ODfname=None,
         experiments="all",
         experimentincludes=False,
         experimentexcludes=False,
@@ -1580,7 +1561,7 @@ class platereader:
         figs: boolean, optional
             If True, a plot of the fit to the dilution data is produced.
         odmatch: float, optional
-            If non-zero, then the corrected OD is rescaled to equal the
+            If not None, then the corrected OD is rescaled to equal the
             measured OD at this value. Only large ODs typically need to be
             corrected.
         cvfn: string
@@ -1594,6 +1575,10 @@ class platereader:
             and confines the third hyperparmater between 1e2 and 1e6.
         gp_results: boolean, optional
             If True, show the results of fitting the Gaussian process
+        ODfname: string, optional
+            The name of the file with the dilution data used to correct OD for
+            its non-linear dependence on numbers of cells. If unspecified, data
+            for haploid budding yeast growing in glucose is used.
         experiments: string or list of strings
             The experiments to include.
         conditions: string or list of strings
@@ -1623,6 +1608,16 @@ class platereader:
             conditionexcludes,
             nomedia=False,
         )
+        # fit dilution data
+        gc = corrections.findODcorrection(
+            self.wdirpath,
+            ODfname,
+            figs=figs,
+            odmatch=odmatch,
+            cvfn=cvfn,
+            bd=bd,
+            gp_results=gp_results,
+        )
         for exp in exps:
             for c in cons:
                 if self.sc[(self.sc.experiment == exp) & (self.sc.condition == c)][
@@ -1630,31 +1625,6 @@ class platereader:
                 ].any():
                     print(exp, ": OD is already corrected for", c)
                 else:
-                    # fit dilution data
-                    if not self.progress["gc"][exp]:
-                        ODfname = (
-                            str(self.progress["ODfname"][exp])
-                            if self.progress["ODfname"][exp]
-                            else None
-                        )
-                        gc = corrections.findODcorrection(
-                            self.wdirpath,
-                            ODfname,
-                            exp,
-                            figs=figs,
-                            odmatch=odmatch,
-                            cvfn=cvfn,
-                            bd=bd,
-                            gp_results=gp_results,
-                        )
-                        self.progress["gc"][exp] = gc
-                        # copy gc to experiments with the same ODfname
-                        for e in self.allexperiments:
-                            if (
-                                self.progress["ODfname"][e]
-                                == self.progress["ODfname"][exp]
-                            ):
-                                self.progress["gc"][e] = gc
                     # correct all wells
                     gc.batchpredict(
                         self.r.query("experiment == @exp and condition == @c")[
